# Pseudo-Labeller
Pseudo Irradience Labeller for generating training labels for other PV generation forecasting, and hindcasts. 

## Install

You can install this package by doing `pip install pseudo-labeller`

## Usage

## Train

## Notes
